@@ -1,5 +1,5 @@
-# WordNet::Extend::Insert.pm version 0.01
-# Updated: 09/19/16
+# WordNet::Extend::Insert.pm version 0.020
+# Updated: 09/29/16
 #                                           
 # Ted Pedersen, University of Minnesota Duluth             
 # tpederse at d.umn.edu
@@ -32,24 +32,27 @@ WordNet.
 
 =head2 Basic Usage Example
 
-use WordNet::Extend::Insert;
+ use WordNet::Extend::Insert;
 
-my $insert = WordNet::Extend::Insert->new();
+ my $insert = WordNet::Extend::Insert->new();
 
-@in1 = ("crackberry","noun","withdef.1", "A BlackBerry, a handheld device considered addictive for its networking capability.");    
-@in2 = ("slackberry","noun","withdef.2", "A mocking name for crackberry.");
+ @in1 = ("crackberry","noun","withdef.1", "A BlackBerry, a handheld device considered addictive for its networking capability.");    
 
-@loc1 = ("withdef.5","cellphone#n#1");
-@loc2 = ("withdef.6","crackberry#n#1");
+ @in2 = ("slackberry","noun","withdef.2", "A mocking name for crackberry.");
 
-$insert->attach(\@in1, \@loc1);
-$insert->merge(\@in2, \@loc2);
+ @loc1 = ("withdef.5","cellphone#n#1");
+
+ @loc2 = ("withdef.6","crackberry#n#1");
+
+ $insert->attach(\@in1, \@loc1);
+
+ $insert->merge(\@in2, \@loc2);
 
 =head1 DESCRIPTION
 
 =head2 Introduction
 
-WordNet is a widely used tool in NLP and other research areas. A drawback of WordNet is the amount of time between updates. WordNet::Extend::Insert aims to allow developers insert their own lemmas into WordNet which can help keep WordNet updated with new language in the world. It can also revert back to the original untouched WordNet if the user makes a mistake or simply wants the untouched WordNet to access.
+WordNet is a widely used tool in NLP and other research areas. A drawback of WordNet is the amount of time between updates. WordNet was last updated and released in December, 2006, and no further updates are planned. WordNet::Extend::Insert aims to allow developers insert their own lemmas into WordNet which can help keep WordNet updated with new language in the world. It can also revert back to the original untouched WordNet (by calling restoreWordNet) if the user makes a mistake or simply wants the untouched WordNet to access.
 
 =over
 =cut
@@ -69,7 +72,7 @@ our ($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 
 @EXPORT = ();
 
-$VERSION = '0.01';
+$VERSION = '0.020';
 
 #**************Variables**********************
 $wn = WordNet::QueryData->new; #to be used to access data from wordnet
@@ -95,7 +98,7 @@ The following methods are defined in this package:
 
 =item $obj->new()
 
-The constructor for WordNet::Extend objects.
+The constructor for WordNet::Extend::Insert objects.
 
 Parameters: none.
 
@@ -120,8 +123,10 @@ sub new
 
 Allows the object to check if any errors have occurred.
 Returns an array ($error, $errString), where $error 
-value equal to 1 represents a warning and greater than that
-represents an error and $errString contains the possible error.
+value equal to 1 represents a warning and 2 represents
+an error with the requested commands. (If a user would
+run attach() without enough arguments, the error code 
+would return 2). $errorString contains what error occurred.
 
 Parameter: None
 
@@ -142,8 +147,9 @@ sub getError()
 =item $obj->attach($newSynset, $location)
 
 Takes in a new synset and inserts it into WordNet at the specified location
-
-by attaching it to the specified location lemma as a hyponym.
+by attaching it to the specified location lemma as a hyponym. The location should
+be represented by "lemma#pos#senseNum". For example, to attach to the 2nd sense
+of the noun window, the location would be "window#n#2".
 
 Parameters: Synset array in form (lemma, part-of-speech, item-id, definition)
 or "word\tpos\titem-id\tdef", and location to be inserted in form  
@@ -187,6 +193,14 @@ sub attach()
 	$write = 0;
     }
 
+    unless (defined $wn->offset("$location[1]"))
+    {
+	my $self = shift;
+	$self->{error} = 2;
+	$self->{errorString} = "Location does not exist in WordNet.";
+	$write = 0;
+    }
+
     if($write == 1)
     {
        	my $newOffset = findNewOffset($newSyn[1]);
@@ -543,7 +557,16 @@ sub attach()
 
 	if($write == 1)#if write was successful, overwrite old files with new.
 	{
-	    #if no backup files exists make for easy revert.
+	    #make backup files for last change
+	    #first remove old last files
+	    unlink glob "$WNSEARCHDICT/*.last";
+
+	    #next make new last files                
+	    copy($indexFile, "$indexFile.last");
+	    copy($dataFile, "$dataFile.last");
+	    copy($senseFile, "$senseFile.last");
+	    
+	    #if no backup files exists for restoreWordnet() make for easy revert.
 	    my $backupcheck = "$indexFile.backup";
 	    unless(-f $backupcheck)
 	    {
@@ -576,8 +599,9 @@ sub attach()
 =item $obj->merge($newSynset, $location)
 
 Takes in a new synset and inserts it into WordNet at the specified location
-
-by merging it into the specified location lemma as a synset.
+by merging it into the specified location lemma as a synset. The location should
+be represented by "lemma#pos#senseNum". For example, to merge to the 2nd sense
+of the noun window, the location would be "window#n#2".
 
 Parameters: Synset array in form (lemma, part-of-speech, item-id, definition)
 or "word\tpos\titem-id\tdef", and location to be inserted in form  
@@ -621,6 +645,14 @@ sub merge()
 	$write = 0;
     }
 
+    unless (defined $wn->offset("$location[1]"))
+    {
+	my $self = shift;
+	$self->{error} = 2;
+	$self->{errorString} = "Location does not exist in WordNet.";
+	$write = 0;
+    }
+    
     if($write == 1)
     {
        	my $newOffset = findNewOffset($newSyn[1]);
@@ -957,7 +989,16 @@ sub merge()
 
 	if($write == 1)#if write was successful, overwrite old files with new.
 	{
-	    #if no backup files exists make for easy revert.
+	    #make backup files for last change
+	    #first remove old last files
+	    unlink glob "$WNSEARCHDICT/*.last";
+
+	    #next make new last files
+	    copy($indexFile, "$indexFile.last");
+	    copy($dataFile, "$dataFile.last");
+	    copy($senseFile, "$senseFile.last");
+	    	    
+	    #if no backup files for restoreWordnet() exists make for easy revert.
 	    my $backupcheck = "$indexFile.backup";
 	    unless(-f $backupcheck)
 	    {
@@ -989,9 +1030,9 @@ sub merge()
 
 =item $obj->restoreWordNet()
 
-Causes all WordNet dict files to be restored to their original
-
-state before any inserts were performed.
+Causes all WordNet\dict files to be restored to their original
+state before any inserts were performed. This is equivalent to 
+installing WordNet\dict fresh on your machine.
 
 Parameter: none
 
@@ -1048,9 +1089,74 @@ sub restoreWordNet()
 	unlink "$WNSEARCHDICT/index.sense";
 
 	move("$WNSEARCHDICT/index.sense.backup", "$WNSEARCHDICT/index.sense");
-    }
-}    
 
+	unlink glob "$WNSEARCHDICT/*.last";
+    }
+}
+
+=item $obj->revertLastChange()
+
+Allows the user to undo the last insert made to WordNet.
+
+Parameter: none
+
+Returns: nothing
+
+=cut
+
+sub revertLastChange()
+{
+    my $backupFlag = 0;
+    
+    if(-f "$WNSEARCHDICT/index.noun.last")
+    {
+	unlink "$WNSEARCHDICT/index.noun";
+	unlink "$WNSEARCHDICT/data.noun";
+	$backupFlag = 1;
+
+	move("$WNSEARCHDICT/index.noun.last", "$WNSEARCHDICT/index.noun");
+	move("$WNSEARCHDICT/data.noun.last", "$WNSEARCHDICT/data.noun");
+    }
+
+    if(-f "$WNSEARCHDICT/index.verb.last")
+    {
+	unlink "$WNSEARCHDICT/index.verb";
+	unlink "$WNSEARCHDICT/data.verb";
+	$backupFlag = 1;
+
+	move("$WNSEARCHDICT/index.verb.last", "$WNSEARCHDICT/index.verb");
+	move("$WNSEARCHDICT/data.verb.last", "$WNSEARCHDICT/data.verb");
+    }
+
+    if(-f "$WNSEARCHDICT/index.adj.last")
+    {
+	unlink "$WNSEARCHDICT/index.adj";
+	unlink "$WNSEARCHDICT/data.adj";
+	$backupFlag = 1;
+
+	move("$WNSEARCHDICT/index.adj.last", "$WNSEARCHDICT/index.adj");
+	move("$WNSEARCHDICT/data.adj.last", "$WNSEARCHDICT/data.adj");
+    }
+
+    if(-f "$WNSEARCHDICT/index.adv.last")
+    {
+	unlink "$WNSEARCHDICT/index.adv";
+	unlink "$WNSEARCHDICT/data.adv";
+	$backupFlag = 1;
+
+	move("$WNSEARCHDICT/index.adv.last", "$WNSEARCHDICT/index.adv");
+	move("$WNSEARCHDICT/data.adv.last", "$WNSEARCHDICT/data.adv");
+    }
+
+    if($backupFlag == 1)
+    {
+	unlink "$WNSEARCHDICT/index.sense";
+
+	move("$WNSEARCHDICT/index.sense.last", "$WNSEARCHDICT/index.sense");
+    }
+
+}
+    
 =item $obj->isNewWord($lemma, $pos)
 
 Takes in a lemma and searches wordnet to see if it exists.
