@@ -1,4 +1,4 @@
-# WordNet::Extend::Locate.pm version 0.01
+# WordNet::Extend::Locate.pm version 0.010
 # Updated: 06/06/16
 #                                           
 # Ted Pedersen, University of Minnesota Duluth             
@@ -34,27 +34,27 @@ lemma should be inserted.
 
 use WordNet::Extend::Locate;
 
-my $insert = WordNet::Extend::Locate->new();
+ my $insert = WordNet::Extend::Locate->new();
 
-$insert->stopList('s/\b(the|is|at)\b//');
+ $insert->stopList('s/\b(the|is|at)\b//');
 
-$insert->setCleanUp(1);
+ $insert->setCleanUp(1);
 
-$insert->preProcessing();
+ $insert->preProcessing();
 
-$insert->toggleCompareGlosses(1,1,0);
+ $insert->toggleCompareGlosses(1,1,0);
 
-$insert->setBonus(25);
+ $insert->setBonus(25);
 
-$insert->toggleRefineSense(0);
+ $insert->toggleRefineSense(0);
 
-@location = $insert->locate("dog\tnoun\twithdef.1\tman\'s best friend");
+ @location = $insert->locate("dog\tnoun\twithdef.1\tman\'s best friend");
 
 =head1 DESCRIPTION
 
 =head2 Introduction
 
-WordNet is a widely used tool in NLP and other research areas. A drawback of WordNet is the amount of time between updates. WordNet::Extend::Locate aims to help users decide where a good place to insert new lemmas into WordNet is. Users can then take the suggestion from Locate and use that with WordNet::Extend::Insert or simply use it as a guiding point and choose their own location.
+WordNet is a widely used tool in NLP and other research areas. A drawback of WordNet is the amount of time between updates. WordNet was last updated and released in December, 2006, and no further updates are planned. WordNet::Extend::Locate aims to help users decide where a good place to insert new lemmas into WordNet is by presenting several different methods to run. Users can then take the suggestion from Locate and use that with WordNet::Extend::Insert or simply use it as a guiding point and choose their own location.
 
 =over
 =cut
@@ -74,7 +74,7 @@ our ($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 
 @EXPORT = ();
 
-$VERSION = '0.01';
+$VERSION = '0.010';
 
 #**************Variables**********************
 $wn = WordNet::QueryData->new; #to be used to access data from wordnet
@@ -117,7 +117,7 @@ The following methods are defined in this package:
 
 =item $obj->new()
 
-The constructor for WordNet::Extend objects.
+The constructor for WordNet::Extend::Locate objects.
 
 Parameters: none.
 
@@ -141,9 +141,12 @@ sub new
 =item $obj->getError()
 
 Allows the object to check if any errors have occurred.
-Returns an array ($error, $errString), where $error 
-value equal to 1 represents a warning and greater than that
-represents an error and $errString contains the possible error.
+Returns an array ($error, $errorString), where $error 
+value equal to 1 represents a warning and 2 represents
+an error and $errString contains the possible error.
+For example, if a user forgets to run preProcessing() before
+a method that relies on it, the error would be 2 and errorString
+would mention that preProcessing had not been run.
 
 Parameter: None
 
